package main

import (
	"fmt"
	"golang.source-fellows.com/pattern/composite/internal/model"
)

func main() {

	auto := model.NewCompoundComponent("auto")

	motor := model.NewSimpleComponent("Motor", 200*model.Kilogram)
	sitze := model.NewCompoundComponent("Sitze")
	sitze.AddChildComponent(model.NewSimpleComponent("Vordersitz links", 28*model.Kilogram))
	sitze.AddChildComponent(model.NewSimpleComponent("Vordersitz rechts", 28*model.Kilogram))
	sitze.AddChildComponent(model.NewSimpleComponent("Rückbank", 62*model.Kilogram))

	auto.AddChildComponent(motor)
	auto.AddChildComponent(sitze)

	fmt.Println(auto.Weight())

}
